Index: main/trunk/greenstone3/build.xml
===================================================================
--- main/trunk/greenstone3/build.xml	(revision 28930)
+++ main/trunk/greenstone3/build.xml	(revision 28937)
@@ -955,12 +955,12 @@
     </if>
     <copy file="${basedir}/resources/cgi/gsdl3site.cfg.in" tofile="${basedir}/resources/cgi/gsdl3site.cfg" overwrite="true"/>
-    <if><bool><available file="${basedir}/resources/java/global.properties"/></bool>
-    <copy file="${basedir}/resources/java/global.properties" tofile="${basedir}/resources/java/global.properties.backup" overwrite="true"/>
-    </if>
-    <copy file="${basedir}/resources/java/global.properties.in" tofile="${basedir}/resources/java/global.properties" overwrite="true"/>
-    <if><bool><available file="${basedir}/resources/java/log4j.properties"/></bool>
-    <copy file="${basedir}/resources/java/log4j.properties" tofile="${basedir}/resources/java/log4j.properties.backup" overwrite="true"/>
-    </if>
-    <copy file="${basedir}/resources/java/log4j.properties.in" tofile="${basedir}/resources/java/log4j.properties" overwrite="true"/>
+    <if><bool><available file="${basedir}/resources/web/global.properties"/></bool>
+    <copy file="${basedir}/resources/web/global.properties" tofile="${basedir}/resources/web/global.properties.backup" overwrite="true"/>
+    </if>
+    <copy file="${basedir}/resources/web/global.properties.in" tofile="${basedir}/resources/web/global.properties" overwrite="true"/>
+    <if><bool><available file="${basedir}/resources/web/log4j.properties"/></bool>
+    <copy file="${basedir}/resources/web/log4j.properties" tofile="${basedir}/resources/web/log4j.properties.backup" overwrite="true"/>
+    </if>
+    <copy file="${basedir}/resources/web/log4j.properties.in" tofile="${basedir}/resources/web/log4j.properties" overwrite="true"/>
   </target>
   <!-- ========== Web app Targets ================================ -->
@@ -1192,6 +1192,6 @@
     <filter token="disable.collection.building" value="${disable.collection.building}"/>
     <copy file="${basedir}/resources/cgi/gsdl3site.cfg" tofile="${web.writablehome}/WEB-INF/cgi/gsdl3site.cfg" filtering="true" overwrite="true"/>
-    <copy file="${basedir}/resources/java/global.properties" tofile="${web.writableclasses}/global.properties" filtering="true" overwrite="true"/>
-    <copy file="${basedir}/resources/java/log4j.properties" tofile="${web.writableclasses}/log4j.properties" filtering="true" overwrite="true"/>
+    <copy file="${basedir}/resources/web/global.properties" tofile="${web.writableclasses}/global.properties" filtering="true" overwrite="true"/>
+    <copy file="${basedir}/resources/web/log4j.properties" tofile="${web.writableclasses}/log4j.properties" filtering="true" overwrite="true"/>
     <if><bool><istrue value="${gsdl3home.isreadonly}"/></bool>
       <!-- uncomment the writablehome properties -->
Index: main/trunk/greenstone3/resources/java/global.properties.in
===================================================================
--- main/trunk/greenstone3/resources/java/global.properties.in	(revision 28930)
+++ 	(revision )
@@ -1,39 +1,0 @@
-## Do not edit. This file is automatically generated from 
-##   <gsdlhome>/resources/java/global.properties.in
-
-## greenstone home
-#If you want to specify the gsdl3.home manually then uncomment this line
-#in resources/java/global.properties.in, not global.properties since
-#the latter is repeatedly re-generated from global.properties.in
-#gsdl3.home=@gsdl3home@
-#gsdl3.writablehome=@gsdl3writablehome@
-gsdl3.version=@gsdl3version@
-
-disable.collection.building=@disable.collection.building@
-
-# for collection building
-perl.path=@perlpath@
-
-# tomcat info
-tomcat.server=@tomcat.server@
-tomcat.port=@tomcat.port@
-tomcat.context=greenstone3
-
-## Proxy setup - set these if you are behind a firewall and you want services that access the internet
-# The proxy server name 
-proxy.host=
-# The proxy server port
-proxy.port=
-# A user name to use when talking to the proxy server 
-proxy.user=
-# A password to use when talking to the proxy server 
-proxy.password=
-
-#outgoing mail setup
-#mail.smtp.host=smtp.myisp.com
-#mail.smtp.username=ispusername
-#mail.smtp.password=isppassword
-#mail.from=ispusername@myisp.com
-
-# flax auxiliary external server url for collocation retrieval
-flax.aux.server=flax.nzdl.org/greenstone3/flax
Index: main/trunk/greenstone3/resources/java/log4j.properties.in
===================================================================
--- main/trunk/greenstone3/resources/java/log4j.properties.in	(revision 28930)
+++ 	(revision )
@@ -1,65 +1,0 @@
-## greenstone home 
-gsdl3.home=@gsdl3home@
-gsdl3.writablehome=@gsdl3writablehome@
-
-##Configure log4j's operation at the meta level                              
-##Observe log4j parsing this file
-#log4j.debug=true
-##Set this to false for log4j to actually obey the log4j.disable property(next)
-log4j.disableOverride=false
-##Disable all logging in all categories for messages with priority equal to
-##or lower than the one given here
-log4j.disable=DEBUG
-
-#####configure the loggers####
-##general logger         
-##log4j.rootCategory=DEBUG, infolog
-## to enable DEBUG, uncomment out the above line and comment out the following line                                    
-log4j.rootCategory=INFO, infolog
-
-##usage logger
-log4j.category.org.greenstone.gsdl3.LibraryServlet=INFO, usagelog
-log4j.additivity.org.greenstone.gsdl3.LibraryServlet=false
-
-##server logger
-##log4j.category.org.greenstone.server=DEBUG, serverlog
-## to enable DEBUG, uncomment out the above line and comment out the following line  
-log4j.category.org.greenstone.server=INFO, serverlog
-log4j.additivity.org.greenstone.server=false
-
-#####configure appenders and their oprions####                                  
-##general logger
-log4j.appender.infolog=org.apache.log4j.RollingFileAppender
-log4j.appender.infolog.File=${gsdl3.writablehome}/logs/greenstone.log
-#Control the maximum log file size
-log4j.appender.infolog.MaxFileSize=10000KB
-#Keep backup file(s) (backups will be in filename.1, .2, .3 etc.)
-log4j.appender.infolog.MaxBackupIndex=3
-
-##usage logger
-log4j.appender.usagelog=org.apache.log4j.RollingFileAppender
-log4j.appender.usagelog.File=${gsdl3.writablehome}/logs/usage.log
-#Control the maximum log file size
-log4j.appender.usagelog.MaxFileSize=10000KB
-
-##Server's logger
-log4j.appender.serverlog=org.apache.log4j.RollingFileAppender
-log4j.appender.serverlog.File=${gsdl3.writablehome}/logs/server.log
-
-
-#####Configure appender layouts and their options#### 
-## general logger layout
-log4j.appender.infolog.layout=org.apache.log4j.PatternLayout
-log4j.appender.infolog.layout.ConversionPattern=%-5p: [%d{yyyy-MM-dd hh:mm:ss}] %C{1}.%M()%n %m%n
-
-##usage logger layout
-# Usage log contains:                                                        
-#      loggingTime + servletName + args (in URL plus saved in a session) +  
-#      remoteAddress + sessionID + browerInfo                               
-log4j.appender.usagelog.layout=org.apache.log4j.PatternLayout
-log4j.appender.usagelog.layout.ConversionPattern=[%d{yyyy-MM-dd hh:mm:ss}] %m%n
-
-##server logger layout
-log4j.appender.serverlog.layout=org.apache.log4j.PatternLayout
-log4j.appender.serverlog.layout.ConversionPattern=%-5p: [%d{yyyy-MM-dd hh:mm:ss}] %C{1}.%M()%n %m%n
-
Index: main/trunk/greenstone3/resources/web/global.properties.in
===================================================================
--- main/trunk/greenstone3/resources/web/global.properties.in	(revision 28937)
+++ main/trunk/greenstone3/resources/web/global.properties.in	(revision 28937)
@@ -0,0 +1,39 @@
+## Do not edit. This file is automatically generated from 
+##   <gsdlhome>/resources/java/global.properties.in
+
+## greenstone home
+#If you want to specify the gsdl3.home manually then uncomment this line
+#in resources/java/global.properties.in, not global.properties since
+#the latter is repeatedly re-generated from global.properties.in
+#gsdl3.home=@gsdl3home@
+#gsdl3.writablehome=@gsdl3writablehome@
+gsdl3.version=@gsdl3version@
+
+disable.collection.building=@disable.collection.building@
+
+# for collection building
+perl.path=@perlpath@
+
+# tomcat info
+tomcat.server=@tomcat.server@
+tomcat.port=@tomcat.port@
+tomcat.context=greenstone3
+
+## Proxy setup - set these if you are behind a firewall and you want services that access the internet
+# The proxy server name 
+proxy.host=
+# The proxy server port
+proxy.port=
+# A user name to use when talking to the proxy server 
+proxy.user=
+# A password to use when talking to the proxy server 
+proxy.password=
+
+#outgoing mail setup
+#mail.smtp.host=smtp.myisp.com
+#mail.smtp.username=ispusername
+#mail.smtp.password=isppassword
+#mail.from=ispusername@myisp.com
+
+# flax auxiliary external server url for collocation retrieval
+flax.aux.server=flax.nzdl.org/greenstone3/flax
Index: main/trunk/greenstone3/resources/web/log4j.properties.in
===================================================================
--- main/trunk/greenstone3/resources/web/log4j.properties.in	(revision 28937)
+++ main/trunk/greenstone3/resources/web/log4j.properties.in	(revision 28937)
@@ -0,0 +1,65 @@
+## greenstone home 
+gsdl3.home=@gsdl3home@
+gsdl3.writablehome=@gsdl3writablehome@
+
+##Configure log4j's operation at the meta level                              
+##Observe log4j parsing this file
+#log4j.debug=true
+##Set this to false for log4j to actually obey the log4j.disable property(next)
+log4j.disableOverride=false
+##Disable all logging in all categories for messages with priority equal to
+##or lower than the one given here
+log4j.disable=DEBUG
+
+#####configure the loggers####
+##general logger         
+##log4j.rootCategory=DEBUG, infolog
+## to enable DEBUG, uncomment out the above line and comment out the following line                                    
+log4j.rootCategory=INFO, infolog
+
+##usage logger
+log4j.category.org.greenstone.gsdl3.LibraryServlet=INFO, usagelog
+log4j.additivity.org.greenstone.gsdl3.LibraryServlet=false
+
+##server logger
+##log4j.category.org.greenstone.server=DEBUG, serverlog
+## to enable DEBUG, uncomment out the above line and comment out the following line  
+log4j.category.org.greenstone.server=INFO, serverlog
+log4j.additivity.org.greenstone.server=false
+
+#####configure appenders and their oprions####                                  
+##general logger
+log4j.appender.infolog=org.apache.log4j.RollingFileAppender
+log4j.appender.infolog.File=${gsdl3.writablehome}/logs/greenstone.log
+#Control the maximum log file size
+log4j.appender.infolog.MaxFileSize=10000KB
+#Keep backup file(s) (backups will be in filename.1, .2, .3 etc.)
+log4j.appender.infolog.MaxBackupIndex=3
+
+##usage logger
+log4j.appender.usagelog=org.apache.log4j.RollingFileAppender
+log4j.appender.usagelog.File=${gsdl3.writablehome}/logs/usage.log
+#Control the maximum log file size
+log4j.appender.usagelog.MaxFileSize=10000KB
+
+##Server's logger
+log4j.appender.serverlog=org.apache.log4j.RollingFileAppender
+log4j.appender.serverlog.File=${gsdl3.writablehome}/logs/server.log
+
+
+#####Configure appender layouts and their options#### 
+## general logger layout
+log4j.appender.infolog.layout=org.apache.log4j.PatternLayout
+log4j.appender.infolog.layout.ConversionPattern=%-5p: [%d{yyyy-MM-dd hh:mm:ss}] %C{1}.%M()%n %m%n
+
+##usage logger layout
+# Usage log contains:                                                        
+#      loggingTime + servletName + args (in URL plus saved in a session) +  
+#      remoteAddress + sessionID + browerInfo                               
+log4j.appender.usagelog.layout=org.apache.log4j.PatternLayout
+log4j.appender.usagelog.layout.ConversionPattern=[%d{yyyy-MM-dd hh:mm:ss}] %m%n
+
+##server logger layout
+log4j.appender.serverlog.layout=org.apache.log4j.PatternLayout
+log4j.appender.serverlog.layout.ConversionPattern=%-5p: [%d{yyyy-MM-dd hh:mm:ss}] %C{1}.%M()%n %m%n
+
Index: main/trunk/greenstone3/src/java/org/greenstone/server/Server3.java
===================================================================
--- main/trunk/greenstone3/src/java/org/greenstone/server/Server3.java	(revision 28930)
+++ main/trunk/greenstone3/src/java/org/greenstone/server/Server3.java	(revision 28937)
@@ -100,5 +100,5 @@
 	File propsFile = new File(propsFolder+"log4j.properties");
 
 	// create it from the template file GS3/resources/java/log4j.properties.in
 	// Always do this => helps make Greenstone3 portable
 
@@ -109,5 +109,5 @@
 		
 		// load the template log4j.properties.in file into logProps
-		FileInputStream infile = new FileInputStream(new File(gsdl_home+File.separator+"resources"+File.separator+"java"+File.separator+"log4j.properties.in"));
+		FileInputStream infile = new FileInputStream(new File(gsdl_home+File.separator+"resources"+File.separator+"web"+File.separator+"log4j.properties"));
 		if(infile != null) {
 		    Properties logProps = new Properties();
@@ -100,5 +100,5 @@
 	File propsFile = new File(propsFolder+"log4j.properties");
 
-	// create it from the template file GS3/resources/java/log4j.properties.in
+	// create it from the template file GS3/resources/web/log4j.properties
 	// Always do this => helps make Greenstone3 portable
 
